@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.23';
+$VERSION = '0.24';
 
 #--------------------------------------------------------------------------
 
@@ -429,86 +429,86 @@ RT: L<http://rt.cpan.org/Public/Dist/Display.html?Name=Finance-Currency-Convert-
 
 __DATA__
 AED|United Arab Emirates, Dirham|&#164;
-AFN|Afghanistan, Afghani|&#164;
-ALL|Albania, Lek|&#164;
-AMD|Armenia, Dram|&#164;
+AFN|Afghan Afghani|&#164;
+ALL|Albanian Lek|&#164;
+AMD|Armenian Dram|&#164;
 ANG|Netherlands Antilles Guilder|&#164;
-AOA|Angola, Kwanza|&#164;
-ARS|Argentina, Peso|&#164;
-AUD|Australia, Dollar|$
-AWG|Aruba, Guilder|&#164;
-AZN|Azerbaijan, New Manat|&#164;
-BAM|Bosnia and Herzegovina, Convertible Marka|&#164;
-BBD|Barbados, Dollar|&#164;
-BDT|Bangladesh, Taka|&#164;
-BGN|Bulgaria, Lev|&#164;
-BHD|Bahrain, Dinar|&#164;
-BIF|Burundi, Franc|&#164;
-BMD|Bermuda, Dollar|&#164;
-BND|Brunei, Dollar|&#164;
-BOB|Bolivia, Boliviano|&#164;
-BRL|Brazil, Real|&#164;
-BSD|Bahamas, Dollar|&#164;
-BTN|Bhutan, Ngultrum|&#164;
-BWP|Botswana, Pula|&#164;
-BYR|Belarus, Ruble|&#164;
-BZD|Belize, Dollar|&#164;
-CAD|Canada, Dollar|$
-CDF|Congo/Kinshasa, Franc|&#164;
+AOA|Angolan Kwanza|&#164;
+ARS|Argentine Peso|&#164;
+AUD|Australian Dollar|$
+AWG|Aruban or Dutch Guilder|&#164;
+AZN|Azerbaijani New Manat|&#164;
+BAM|Bosnian Convertible Marka|&#164;
+BBD|Barbadian or Bajan Dollar|&#164;
+BDT|Bangladeshi Taka|&#164;
+BGN|Bulgarian Lev|&#164;
+BHD|Bahraini Dinar|&#164;
+BIF|Burundian Franc|&#164;
+BMD|Bermudian Dollar|&#164;
+BND|Bruneian Dollar|&#164;
+BOB|Bolivian Boliviano|&#164;
+BRL|Brazilian Real|&#164;
+BSD|Bahamian Dollar|&#164;
+BTN|Bhutanese Ngultrum|&#164;
+BWP|Botswana Pula|&#164;
+BYR|Belarusian Ruble|&#164;
+BZD|Belizean Dollar|&#164;
+CAD|Canadian Dollar|$
+CDF|Congolese Franc|&#164;
 CHF|Switzerland, Franc|&#164;
-CLP|Chile, Peso|&#164;
-CNY|China, Yuan Renminbi|&#164;
-COP|Colombia, Peso|&#164;
-CRC|Costa Rica, Colon|&#164;
-CUC|Cuba, Convertible Peso|&#164;
-CUP|Cuba, Peso|&#164;
-CVE|Cape Verde, Escudo|&#164;
-CZK|Czech Republic, Koruna|&#164;
-DJF|Djibouti, Franc|&#164;
-DKK|Denmark, Krone|&#164;
-DOP|Dominican Republic, Peso|&#164;
-DZD|Algeria, Dinar|&#164;
+CLP|Chilean Peso|&#164;
+CNY|Chinese Yuan Renminbi|&#164;
+COP|Colombian Peso|&#164;
+CRC|Costa Rican Colon|&#164;
+CUC|Cuban Convertible Peso|&#164;
+CUP|Cuban Peso|&#164;
+CVE|Cape Verdean Escudo|&#164;
+CZK|Czech Koruna|&#164;
+DJF|Djiboutian Franc|&#164;
+DKK|Danish Krone|&#164;
+DOP|Dominican Peso|&#164;
+DZD|Algerian Dinar|&#164;
 EEK|Estonia, Kroon|&#164;
-EGP|Egypt, Pound|&#164;
-ERN|Eritrea, Nakfa|&#164;
-ETB|Ethiopia, Birr|&#164;
+EGP|Egyptian Pound|&#164;
+ERN|Eritrean Nakfa|&#164;
+ETB|Ethiopian Birr|&#164;
 EUR|Euro|&#8364;
-FJD|Fiji, Dollar|&#164;
-FKP|Falkland Islands, Pound|&#164;
+FJD|Fijian Dollar|&#164;
+FKP|Falkland Island Pound|&#164;
 GBP|Great Britain, Pound|&#163;
-GEL|Georgia, Lari|&#164;
-GGP|Guernsey, Pound|&#164;
-GHS|Ghana, Cedi|&#164;
-GIP|Gibraltar, Pound|&#164;
-GMD|Gambia, Dalasi|&#164;
-GNF|Guinea, Franc|&#164;
-GTQ|Guatemala, Quetzal|&#164;
-GYD|Guyana, Dollar|&#164;
-HKD|Hong Kong, Dollar|&#164;
-HNL|Honduras, Lempira|&#164;
-HRK|Croatia, Kuna|&#164;
-HTG|Haiti, Gourde|&#164;
-HUF|Hungary, Forint|&#164;
-IDR|Indonesia, Rupiah|&#164;
-ILS|Israel, New Shekel|&#8362;
-IMP|Isle of Man, Pound|&#164;
-INR|India, Rupee|&#8360;
-IQD|Iraq, Dinar|&#164;
-IRR|Iran, Rial|&#164;
-ISK|Iceland, Krona|&#164;
-JEP|Jersey, Pound|&#164;
-JMD|Jamaica, Dollar|&#164;
-JOD|Jordan, Dinar|&#164;
-JPY|Japan, Yen|&#165;
-KES|Kenya, Shilling|&#164;
+GEL|Georgian Lari|&#164;
+GGP|Guernsey Pound|&#164;
+GHS|Ghanaian Cedi|&#164;
+GIP|Gibraltar Pound|&#164;
+GMD|Gambian Dalasi|&#164;
+GNF|Guinean Franc|&#164;
+GTQ|Guatemalan Quetzal|&#164;
+GYD|Guyanese Dollar|&#164;
+HKD|Hong Kong Dollar|&#164;
+HNL|Honduran Lempira|&#164;
+HRK|Croatian Kuna|&#164;
+HTG|Haitian Gourde|&#164;
+HUF|Hungarian Forint|&#164;
+IDR|Indonesian Rupiah|&#164;
+ILS|Israeli Shekel|&#8362;
+IMP|Isle of Man Pound|&#164;
+INR|Indian Rupee|&#8360;
+IQD|Iraqi Dinar|&#164;
+IRR|Iranian Rial|&#164;
+ISK|Icelandic Krona|&#164;
+JEP|Jersey Pound|&#164;
+JMD|Jamaican Dollar|&#164;
+JOD|Jordanian Dinar|&#164;
+JPY|Japanese Yen|&#165;
+KES|Kenyan Shilling|&#164;
 KGS|Kyrgyzstan, Som|&#164;
-KHR|Cambodia, Riel|&#164;
-KMF|Comoros, Franc|&#164;
+KHR|Cambodian Riel|&#164;
+KMF|Comoran Franc|&#164;
 KPW|North Korea, Won|&#164;
 KRW|South Korea, Won|&#8361;
 KWD|Kuwait, Dinar|&#164;
-KYD|Cayman Islands, Dollar|&#164;
-KZT|Kazakhstan, Tenge|&#164;
+KYD|Caymanian Dollar|&#164;
+KZT|Kazakhstani Tenge|&#164;
 LAK|Laos, Kip|&#164;
 LBP|Lebanon, Pound|&#164;
 LKR|Sri Lanka, Rupee|&#164;
@@ -521,8 +521,6 @@ MAD|Morocco, Dirham|&#164;
 MDL|Moldova, Leu|&#164;
 MGA|Madagascar, Ariary|&#164;
 MKD|Macedonia, Denar|&#164;
-MMK|Burma, Kyat|&#164;
-MMK|Myanmar, Kyat|&#164;
 MNT|Mongolia, Tughrik|&#164;
 MOP|Macau, Pataca|&#164;
 MRO|Mauritania, Ouguiya|&#164;
@@ -564,7 +562,7 @@ SOS|Somalia, Shilling|&#164;
 SPL|Seborga, Luigino|&#164;
 SRD|Suriname, Dollar|&#164;
 STD|So Tome and Principe, Dobra|&#164;
-SVC|El Salvador, Colon|&#164;
+SVC|Salvadoran Colon|&#164;
 SYP|Syria, Pound|&#164;
 SZL|Swaziland, Lilangeni|&#164;
 THB|Thailand, Baht|&#3647;
@@ -585,16 +583,15 @@ UZS|Uzbekistan, Som|&#164;
 VEF|Venezuela, Bolivar Fuerte|&#164;
 VND|Vietnam, Dong|&#164;
 VUV|Vanuatu, Vatu|&#164;
-WST|Samoa, Tala|&#164;
-WST|Western Samoa, Tala|&#164;
-XAF|CFA Communaut Financire Africaine BEAC Franc|&#164;
+XAF|Central African CFA Franc BEAC|&#164;
 XAG|Silver Ounce|&#164;
 XAU|Gold Ounce|&#164;
+XBT|Bitcoin|&#164;
 XCD|East Caribbean Dollar|&#164;
-XDR|International Monetary Fund Special Drawing Right|&#164;
-XOF|CFA Communaut Financire Africaine BCEAO Franc|&#164;
+XDR|IMF Special Drawing Rights|&#164;
+XOF|CFA Franc|&#164;
 XPD|Palladium Ounce|&#164;
-XPF|Comptoirs Franais du Pacifique Franc|&#164;
+XPF|CFP Franc|&#164;
 XPT|Platinum Ounce|&#164;
 YER|Yemen, Rial|&#164;
 ZAR|South Africa, Rand|&#164;
